@@ -11,7 +11,7 @@
 #include <kdev-pg-list.h>
 
 
-# 58 "/chakra/desktop/kdev-php/src/kdev-php-5.3.3/parser/php.g" 1
+# 58 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 92 "/chakra/desktop/kdev-php/src/kdev-php-5.3.3/parser/php.g" 1
+# 92 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
 
 class Lexer;
 
@@ -225,7 +225,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 147 "/chakra/desktop/kdev-php/src/kdev-php-5.3.3/parser/php.g" 1
+# 147 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
@@ -1009,6 +1009,7 @@ struct KDEVPHPPARSER_EXPORT ScalarAst: public AstNode
 
     CommonScalarAst *commonScalar;
     ConstantOrClassConstAst *constantOrClassConst;
+    const KDevPG::ListNode<DimListItemAst *> *offsetItemSequence;
     qint64 varname;
     EncapsListAst *encapsList;
     StringIndexSpecifierAst *stringIndex;
